@@ -43,7 +43,6 @@ where
     U: ?Sized,
 {
     /// Register concrete type `I` as an implementor of `U`.
-    #[inline(always)]
     fn register<I>(&mut self)
     where
         I: 'static + Unsize<U>,
@@ -56,22 +55,20 @@ where
     }
 
     /// Whether `data` is registered as an implementor of `U`.
-    #[inline(always)]
     fn implements<'a, P>(&self, data: P) -> bool
     where
-        P: Coercible,
+        P: Coercible<'a>,
     {
         self.contains(data.innermost_type_id())
     }
 
     /// Downcast `pointer` to `P::Coerced<U>`, if registered as an implementor
     /// of `U`.
-    #[inline(always)]
-    fn downcast<'a, P>(&self, pointer: P) -> Result<P::Coerced<'a, U>, P>
+    fn downcast<'a, P>(&self, pointer: P) -> Result<P::Coerced<U>, P>
     where
         P: Pointer<'a>,
-        P::Coerced<'a, U>: Sized,
-        P::Target: Coercible,
+        P::Coerced<U>: Sized,
+        P::Target: Coercible<'a>,
         Coerced<'a, P::Target, U>: ptr::Pointee<Metadata = Metadata<U>>,
     {
         unsafe {
